Author: julianfoad
Date: Mon Jun 6 11:00:37 2011
New Revision: 1132593
URL: http://svn.apache.org/viewvc?rev=1132593&view=rev
Log:
* subversion/include/svn_client.h
(svn_client_upgrade): Rename 'dir' to 'wcroot_dir' and extend doc string.
Modified:
subversion/trunk/subversion/include/svn_client.h
Modified: subversion/trunk/subversion/include/svn_client.h
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=1132593&r1=1132592&r2=1132593&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_client.h (original)
+++ subversion/trunk/subversion/include/svn_client.h Mon Jun 6 11:00:37 2011
@@ -3574,14 +3574,15 @@ svn_client_cleanup(const char *dir,
* @{
*/
/** Recursively upgrade a working copy to a new metadata storage format.
*
* Use @a scratch_pool for any temporary allocations.
*
* @since New in 1.7.
*/
svn_error_t *
-svn_client_upgrade(const char *dir,
+svn_client_upgrade(const char *wcroot_dir,
svn_client_ctx_t *ctx,
apr_pool_t *scratch_pool);
@@ -3574,14 +3574,15 @@ svn_client_cleanup(const char *dir,
* @{
*/
-/** Recursively upgrade a working copy to a new metadata storage format.
+/** Recursively upgrade a working copy from any older format to the current
+ * WC metadata storage format. @a wcroot_dir is the path to the WC root.
*
* Use @a scratch_pool for any temporary allocations.